// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: imu_sensor.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_imu_5fsensor_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_imu_5fsensor_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3019000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3019004 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "sensor_noise.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_imu_5fsensor_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_imu_5fsensor_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[3]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const uint32_t offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_imu_5fsensor_2eproto;
namespace gazebo {
namespace msgs {
class IMUSensor;
struct IMUSensorDefaultTypeInternal;
GZ_MSGS_VISIBLE extern IMUSensorDefaultTypeInternal _IMUSensor_default_instance_;
class IMUSensor_AngularVelocity;
struct IMUSensor_AngularVelocityDefaultTypeInternal;
GZ_MSGS_VISIBLE extern IMUSensor_AngularVelocityDefaultTypeInternal _IMUSensor_AngularVelocity_default_instance_;
class IMUSensor_LinearAcceleration;
struct IMUSensor_LinearAccelerationDefaultTypeInternal;
GZ_MSGS_VISIBLE extern IMUSensor_LinearAccelerationDefaultTypeInternal _IMUSensor_LinearAcceleration_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::IMUSensor* Arena::CreateMaybeMessage<::gazebo::msgs::IMUSensor>(Arena*);
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::IMUSensor_AngularVelocity* Arena::CreateMaybeMessage<::gazebo::msgs::IMUSensor_AngularVelocity>(Arena*);
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::IMUSensor_LinearAcceleration* Arena::CreateMaybeMessage<::gazebo::msgs::IMUSensor_LinearAcceleration>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE IMUSensor_AngularVelocity final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.IMUSensor.AngularVelocity) */ {
 public:
  inline IMUSensor_AngularVelocity() : IMUSensor_AngularVelocity(nullptr) {}
  ~IMUSensor_AngularVelocity() override;
  explicit constexpr IMUSensor_AngularVelocity(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  IMUSensor_AngularVelocity(const IMUSensor_AngularVelocity& from);
  IMUSensor_AngularVelocity(IMUSensor_AngularVelocity&& from) noexcept
    : IMUSensor_AngularVelocity() {
    *this = ::std::move(from);
  }

  inline IMUSensor_AngularVelocity& operator=(const IMUSensor_AngularVelocity& from) {
    CopyFrom(from);
    return *this;
  }
  inline IMUSensor_AngularVelocity& operator=(IMUSensor_AngularVelocity&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const IMUSensor_AngularVelocity& default_instance() {
    return *internal_default_instance();
  }
  static inline const IMUSensor_AngularVelocity* internal_default_instance() {
    return reinterpret_cast<const IMUSensor_AngularVelocity*>(
               &_IMUSensor_AngularVelocity_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(IMUSensor_AngularVelocity& a, IMUSensor_AngularVelocity& b) {
    a.Swap(&b);
  }
  inline void Swap(IMUSensor_AngularVelocity* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(IMUSensor_AngularVelocity* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  IMUSensor_AngularVelocity* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<IMUSensor_AngularVelocity>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const IMUSensor_AngularVelocity& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const IMUSensor_AngularVelocity& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(IMUSensor_AngularVelocity* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.IMUSensor.AngularVelocity";
  }
  protected:
  explicit IMUSensor_AngularVelocity(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kXNoiseFieldNumber = 1,
    kYNoiseFieldNumber = 2,
    kZNoiseFieldNumber = 3,
  };
  // optional .gazebo.msgs.SensorNoise x_noise = 1;
  bool has_x_noise() const;
  private:
  bool _internal_has_x_noise() const;
  public:
  void clear_x_noise();
  const ::gazebo::msgs::SensorNoise& x_noise() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::SensorNoise* release_x_noise();
  ::gazebo::msgs::SensorNoise* mutable_x_noise();
  void set_allocated_x_noise(::gazebo::msgs::SensorNoise* x_noise);
  private:
  const ::gazebo::msgs::SensorNoise& _internal_x_noise() const;
  ::gazebo::msgs::SensorNoise* _internal_mutable_x_noise();
  public:
  void unsafe_arena_set_allocated_x_noise(
      ::gazebo::msgs::SensorNoise* x_noise);
  ::gazebo::msgs::SensorNoise* unsafe_arena_release_x_noise();

  // optional .gazebo.msgs.SensorNoise y_noise = 2;
  bool has_y_noise() const;
  private:
  bool _internal_has_y_noise() const;
  public:
  void clear_y_noise();
  const ::gazebo::msgs::SensorNoise& y_noise() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::SensorNoise* release_y_noise();
  ::gazebo::msgs::SensorNoise* mutable_y_noise();
  void set_allocated_y_noise(::gazebo::msgs::SensorNoise* y_noise);
  private:
  const ::gazebo::msgs::SensorNoise& _internal_y_noise() const;
  ::gazebo::msgs::SensorNoise* _internal_mutable_y_noise();
  public:
  void unsafe_arena_set_allocated_y_noise(
      ::gazebo::msgs::SensorNoise* y_noise);
  ::gazebo::msgs::SensorNoise* unsafe_arena_release_y_noise();

  // optional .gazebo.msgs.SensorNoise z_noise = 3;
  bool has_z_noise() const;
  private:
  bool _internal_has_z_noise() const;
  public:
  void clear_z_noise();
  const ::gazebo::msgs::SensorNoise& z_noise() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::SensorNoise* release_z_noise();
  ::gazebo::msgs::SensorNoise* mutable_z_noise();
  void set_allocated_z_noise(::gazebo::msgs::SensorNoise* z_noise);
  private:
  const ::gazebo::msgs::SensorNoise& _internal_z_noise() const;
  ::gazebo::msgs::SensorNoise* _internal_mutable_z_noise();
  public:
  void unsafe_arena_set_allocated_z_noise(
      ::gazebo::msgs::SensorNoise* z_noise);
  ::gazebo::msgs::SensorNoise* unsafe_arena_release_z_noise();

  // @@protoc_insertion_point(class_scope:gazebo.msgs.IMUSensor.AngularVelocity)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::gazebo::msgs::SensorNoise* x_noise_;
  ::gazebo::msgs::SensorNoise* y_noise_;
  ::gazebo::msgs::SensorNoise* z_noise_;
  friend struct ::TableStruct_imu_5fsensor_2eproto;
};
// -------------------------------------------------------------------

class GZ_MSGS_VISIBLE IMUSensor_LinearAcceleration final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.IMUSensor.LinearAcceleration) */ {
 public:
  inline IMUSensor_LinearAcceleration() : IMUSensor_LinearAcceleration(nullptr) {}
  ~IMUSensor_LinearAcceleration() override;
  explicit constexpr IMUSensor_LinearAcceleration(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  IMUSensor_LinearAcceleration(const IMUSensor_LinearAcceleration& from);
  IMUSensor_LinearAcceleration(IMUSensor_LinearAcceleration&& from) noexcept
    : IMUSensor_LinearAcceleration() {
    *this = ::std::move(from);
  }

  inline IMUSensor_LinearAcceleration& operator=(const IMUSensor_LinearAcceleration& from) {
    CopyFrom(from);
    return *this;
  }
  inline IMUSensor_LinearAcceleration& operator=(IMUSensor_LinearAcceleration&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const IMUSensor_LinearAcceleration& default_instance() {
    return *internal_default_instance();
  }
  static inline const IMUSensor_LinearAcceleration* internal_default_instance() {
    return reinterpret_cast<const IMUSensor_LinearAcceleration*>(
               &_IMUSensor_LinearAcceleration_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(IMUSensor_LinearAcceleration& a, IMUSensor_LinearAcceleration& b) {
    a.Swap(&b);
  }
  inline void Swap(IMUSensor_LinearAcceleration* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(IMUSensor_LinearAcceleration* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  IMUSensor_LinearAcceleration* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<IMUSensor_LinearAcceleration>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const IMUSensor_LinearAcceleration& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const IMUSensor_LinearAcceleration& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(IMUSensor_LinearAcceleration* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.IMUSensor.LinearAcceleration";
  }
  protected:
  explicit IMUSensor_LinearAcceleration(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kXNoiseFieldNumber = 1,
    kYNoiseFieldNumber = 2,
    kZNoiseFieldNumber = 3,
  };
  // optional .gazebo.msgs.SensorNoise x_noise = 1;
  bool has_x_noise() const;
  private:
  bool _internal_has_x_noise() const;
  public:
  void clear_x_noise();
  const ::gazebo::msgs::SensorNoise& x_noise() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::SensorNoise* release_x_noise();
  ::gazebo::msgs::SensorNoise* mutable_x_noise();
  void set_allocated_x_noise(::gazebo::msgs::SensorNoise* x_noise);
  private:
  const ::gazebo::msgs::SensorNoise& _internal_x_noise() const;
  ::gazebo::msgs::SensorNoise* _internal_mutable_x_noise();
  public:
  void unsafe_arena_set_allocated_x_noise(
      ::gazebo::msgs::SensorNoise* x_noise);
  ::gazebo::msgs::SensorNoise* unsafe_arena_release_x_noise();

  // optional .gazebo.msgs.SensorNoise y_noise = 2;
  bool has_y_noise() const;
  private:
  bool _internal_has_y_noise() const;
  public:
  void clear_y_noise();
  const ::gazebo::msgs::SensorNoise& y_noise() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::SensorNoise* release_y_noise();
  ::gazebo::msgs::SensorNoise* mutable_y_noise();
  void set_allocated_y_noise(::gazebo::msgs::SensorNoise* y_noise);
  private:
  const ::gazebo::msgs::SensorNoise& _internal_y_noise() const;
  ::gazebo::msgs::SensorNoise* _internal_mutable_y_noise();
  public:
  void unsafe_arena_set_allocated_y_noise(
      ::gazebo::msgs::SensorNoise* y_noise);
  ::gazebo::msgs::SensorNoise* unsafe_arena_release_y_noise();

  // optional .gazebo.msgs.SensorNoise z_noise = 3;
  bool has_z_noise() const;
  private:
  bool _internal_has_z_noise() const;
  public:
  void clear_z_noise();
  const ::gazebo::msgs::SensorNoise& z_noise() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::SensorNoise* release_z_noise();
  ::gazebo::msgs::SensorNoise* mutable_z_noise();
  void set_allocated_z_noise(::gazebo::msgs::SensorNoise* z_noise);
  private:
  const ::gazebo::msgs::SensorNoise& _internal_z_noise() const;
  ::gazebo::msgs::SensorNoise* _internal_mutable_z_noise();
  public:
  void unsafe_arena_set_allocated_z_noise(
      ::gazebo::msgs::SensorNoise* z_noise);
  ::gazebo::msgs::SensorNoise* unsafe_arena_release_z_noise();

  // @@protoc_insertion_point(class_scope:gazebo.msgs.IMUSensor.LinearAcceleration)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::gazebo::msgs::SensorNoise* x_noise_;
  ::gazebo::msgs::SensorNoise* y_noise_;
  ::gazebo::msgs::SensorNoise* z_noise_;
  friend struct ::TableStruct_imu_5fsensor_2eproto;
};
// -------------------------------------------------------------------

class GZ_MSGS_VISIBLE IMUSensor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.IMUSensor) */ {
 public:
  inline IMUSensor() : IMUSensor(nullptr) {}
  ~IMUSensor() override;
  explicit constexpr IMUSensor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  IMUSensor(const IMUSensor& from);
  IMUSensor(IMUSensor&& from) noexcept
    : IMUSensor() {
    *this = ::std::move(from);
  }

  inline IMUSensor& operator=(const IMUSensor& from) {
    CopyFrom(from);
    return *this;
  }
  inline IMUSensor& operator=(IMUSensor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const IMUSensor& default_instance() {
    return *internal_default_instance();
  }
  static inline const IMUSensor* internal_default_instance() {
    return reinterpret_cast<const IMUSensor*>(
               &_IMUSensor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    2;

  friend void swap(IMUSensor& a, IMUSensor& b) {
    a.Swap(&b);
  }
  inline void Swap(IMUSensor* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(IMUSensor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  IMUSensor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<IMUSensor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const IMUSensor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const IMUSensor& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(IMUSensor* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.IMUSensor";
  }
  protected:
  explicit IMUSensor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef IMUSensor_AngularVelocity AngularVelocity;
  typedef IMUSensor_LinearAcceleration LinearAcceleration;

  // accessors -------------------------------------------------------

  enum : int {
    kAngularVelocityFieldNumber = 1,
    kLinearAccelerationFieldNumber = 2,
  };
  // optional .gazebo.msgs.IMUSensor.AngularVelocity angular_velocity = 1;
  bool has_angular_velocity() const;
  private:
  bool _internal_has_angular_velocity() const;
  public:
  void clear_angular_velocity();
  const ::gazebo::msgs::IMUSensor_AngularVelocity& angular_velocity() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::IMUSensor_AngularVelocity* release_angular_velocity();
  ::gazebo::msgs::IMUSensor_AngularVelocity* mutable_angular_velocity();
  void set_allocated_angular_velocity(::gazebo::msgs::IMUSensor_AngularVelocity* angular_velocity);
  private:
  const ::gazebo::msgs::IMUSensor_AngularVelocity& _internal_angular_velocity() const;
  ::gazebo::msgs::IMUSensor_AngularVelocity* _internal_mutable_angular_velocity();
  public:
  void unsafe_arena_set_allocated_angular_velocity(
      ::gazebo::msgs::IMUSensor_AngularVelocity* angular_velocity);
  ::gazebo::msgs::IMUSensor_AngularVelocity* unsafe_arena_release_angular_velocity();

  // optional .gazebo.msgs.IMUSensor.LinearAcceleration linear_acceleration = 2;
  bool has_linear_acceleration() const;
  private:
  bool _internal_has_linear_acceleration() const;
  public:
  void clear_linear_acceleration();
  const ::gazebo::msgs::IMUSensor_LinearAcceleration& linear_acceleration() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::IMUSensor_LinearAcceleration* release_linear_acceleration();
  ::gazebo::msgs::IMUSensor_LinearAcceleration* mutable_linear_acceleration();
  void set_allocated_linear_acceleration(::gazebo::msgs::IMUSensor_LinearAcceleration* linear_acceleration);
  private:
  const ::gazebo::msgs::IMUSensor_LinearAcceleration& _internal_linear_acceleration() const;
  ::gazebo::msgs::IMUSensor_LinearAcceleration* _internal_mutable_linear_acceleration();
  public:
  void unsafe_arena_set_allocated_linear_acceleration(
      ::gazebo::msgs::IMUSensor_LinearAcceleration* linear_acceleration);
  ::gazebo::msgs::IMUSensor_LinearAcceleration* unsafe_arena_release_linear_acceleration();

  // @@protoc_insertion_point(class_scope:gazebo.msgs.IMUSensor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::gazebo::msgs::IMUSensor_AngularVelocity* angular_velocity_;
  ::gazebo::msgs::IMUSensor_LinearAcceleration* linear_acceleration_;
  friend struct ::TableStruct_imu_5fsensor_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// IMUSensor_AngularVelocity

// optional .gazebo.msgs.SensorNoise x_noise = 1;
inline bool IMUSensor_AngularVelocity::_internal_has_x_noise() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || x_noise_ != nullptr);
  return value;
}
inline bool IMUSensor_AngularVelocity::has_x_noise() const {
  return _internal_has_x_noise();
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_AngularVelocity::_internal_x_noise() const {
  const ::gazebo::msgs::SensorNoise* p = x_noise_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::SensorNoise&>(
      ::gazebo::msgs::_SensorNoise_default_instance_);
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_AngularVelocity::x_noise() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.IMUSensor.AngularVelocity.x_noise)
  return _internal_x_noise();
}
inline void IMUSensor_AngularVelocity::unsafe_arena_set_allocated_x_noise(
    ::gazebo::msgs::SensorNoise* x_noise) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(x_noise_);
  }
  x_noise_ = x_noise;
  if (x_noise) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.IMUSensor.AngularVelocity.x_noise)
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::release_x_noise() {
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::SensorNoise* temp = x_noise_;
  x_noise_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::unsafe_arena_release_x_noise() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.IMUSensor.AngularVelocity.x_noise)
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::SensorNoise* temp = x_noise_;
  x_noise_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::_internal_mutable_x_noise() {
  _has_bits_[0] |= 0x00000001u;
  if (x_noise_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::SensorNoise>(GetArenaForAllocation());
    x_noise_ = p;
  }
  return x_noise_;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::mutable_x_noise() {
  ::gazebo::msgs::SensorNoise* _msg = _internal_mutable_x_noise();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.IMUSensor.AngularVelocity.x_noise)
  return _msg;
}
inline void IMUSensor_AngularVelocity::set_allocated_x_noise(::gazebo::msgs::SensorNoise* x_noise) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(x_noise_);
  }
  if (x_noise) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(x_noise));
    if (message_arena != submessage_arena) {
      x_noise = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, x_noise, submessage_arena);
    }
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  x_noise_ = x_noise;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.IMUSensor.AngularVelocity.x_noise)
}

// optional .gazebo.msgs.SensorNoise y_noise = 2;
inline bool IMUSensor_AngularVelocity::_internal_has_y_noise() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || y_noise_ != nullptr);
  return value;
}
inline bool IMUSensor_AngularVelocity::has_y_noise() const {
  return _internal_has_y_noise();
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_AngularVelocity::_internal_y_noise() const {
  const ::gazebo::msgs::SensorNoise* p = y_noise_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::SensorNoise&>(
      ::gazebo::msgs::_SensorNoise_default_instance_);
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_AngularVelocity::y_noise() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.IMUSensor.AngularVelocity.y_noise)
  return _internal_y_noise();
}
inline void IMUSensor_AngularVelocity::unsafe_arena_set_allocated_y_noise(
    ::gazebo::msgs::SensorNoise* y_noise) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(y_noise_);
  }
  y_noise_ = y_noise;
  if (y_noise) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.IMUSensor.AngularVelocity.y_noise)
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::release_y_noise() {
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::SensorNoise* temp = y_noise_;
  y_noise_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::unsafe_arena_release_y_noise() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.IMUSensor.AngularVelocity.y_noise)
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::SensorNoise* temp = y_noise_;
  y_noise_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::_internal_mutable_y_noise() {
  _has_bits_[0] |= 0x00000002u;
  if (y_noise_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::SensorNoise>(GetArenaForAllocation());
    y_noise_ = p;
  }
  return y_noise_;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::mutable_y_noise() {
  ::gazebo::msgs::SensorNoise* _msg = _internal_mutable_y_noise();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.IMUSensor.AngularVelocity.y_noise)
  return _msg;
}
inline void IMUSensor_AngularVelocity::set_allocated_y_noise(::gazebo::msgs::SensorNoise* y_noise) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(y_noise_);
  }
  if (y_noise) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(y_noise));
    if (message_arena != submessage_arena) {
      y_noise = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, y_noise, submessage_arena);
    }
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  y_noise_ = y_noise;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.IMUSensor.AngularVelocity.y_noise)
}

// optional .gazebo.msgs.SensorNoise z_noise = 3;
inline bool IMUSensor_AngularVelocity::_internal_has_z_noise() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  PROTOBUF_ASSUME(!value || z_noise_ != nullptr);
  return value;
}
inline bool IMUSensor_AngularVelocity::has_z_noise() const {
  return _internal_has_z_noise();
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_AngularVelocity::_internal_z_noise() const {
  const ::gazebo::msgs::SensorNoise* p = z_noise_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::SensorNoise&>(
      ::gazebo::msgs::_SensorNoise_default_instance_);
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_AngularVelocity::z_noise() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.IMUSensor.AngularVelocity.z_noise)
  return _internal_z_noise();
}
inline void IMUSensor_AngularVelocity::unsafe_arena_set_allocated_z_noise(
    ::gazebo::msgs::SensorNoise* z_noise) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(z_noise_);
  }
  z_noise_ = z_noise;
  if (z_noise) {
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.IMUSensor.AngularVelocity.z_noise)
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::release_z_noise() {
  _has_bits_[0] &= ~0x00000004u;
  ::gazebo::msgs::SensorNoise* temp = z_noise_;
  z_noise_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::unsafe_arena_release_z_noise() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.IMUSensor.AngularVelocity.z_noise)
  _has_bits_[0] &= ~0x00000004u;
  ::gazebo::msgs::SensorNoise* temp = z_noise_;
  z_noise_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::_internal_mutable_z_noise() {
  _has_bits_[0] |= 0x00000004u;
  if (z_noise_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::SensorNoise>(GetArenaForAllocation());
    z_noise_ = p;
  }
  return z_noise_;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_AngularVelocity::mutable_z_noise() {
  ::gazebo::msgs::SensorNoise* _msg = _internal_mutable_z_noise();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.IMUSensor.AngularVelocity.z_noise)
  return _msg;
}
inline void IMUSensor_AngularVelocity::set_allocated_z_noise(::gazebo::msgs::SensorNoise* z_noise) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(z_noise_);
  }
  if (z_noise) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(z_noise));
    if (message_arena != submessage_arena) {
      z_noise = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, z_noise, submessage_arena);
    }
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  z_noise_ = z_noise;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.IMUSensor.AngularVelocity.z_noise)
}

// -------------------------------------------------------------------

// IMUSensor_LinearAcceleration

// optional .gazebo.msgs.SensorNoise x_noise = 1;
inline bool IMUSensor_LinearAcceleration::_internal_has_x_noise() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || x_noise_ != nullptr);
  return value;
}
inline bool IMUSensor_LinearAcceleration::has_x_noise() const {
  return _internal_has_x_noise();
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_LinearAcceleration::_internal_x_noise() const {
  const ::gazebo::msgs::SensorNoise* p = x_noise_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::SensorNoise&>(
      ::gazebo::msgs::_SensorNoise_default_instance_);
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_LinearAcceleration::x_noise() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.IMUSensor.LinearAcceleration.x_noise)
  return _internal_x_noise();
}
inline void IMUSensor_LinearAcceleration::unsafe_arena_set_allocated_x_noise(
    ::gazebo::msgs::SensorNoise* x_noise) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(x_noise_);
  }
  x_noise_ = x_noise;
  if (x_noise) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.IMUSensor.LinearAcceleration.x_noise)
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::release_x_noise() {
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::SensorNoise* temp = x_noise_;
  x_noise_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::unsafe_arena_release_x_noise() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.IMUSensor.LinearAcceleration.x_noise)
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::SensorNoise* temp = x_noise_;
  x_noise_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::_internal_mutable_x_noise() {
  _has_bits_[0] |= 0x00000001u;
  if (x_noise_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::SensorNoise>(GetArenaForAllocation());
    x_noise_ = p;
  }
  return x_noise_;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::mutable_x_noise() {
  ::gazebo::msgs::SensorNoise* _msg = _internal_mutable_x_noise();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.IMUSensor.LinearAcceleration.x_noise)
  return _msg;
}
inline void IMUSensor_LinearAcceleration::set_allocated_x_noise(::gazebo::msgs::SensorNoise* x_noise) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(x_noise_);
  }
  if (x_noise) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(x_noise));
    if (message_arena != submessage_arena) {
      x_noise = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, x_noise, submessage_arena);
    }
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  x_noise_ = x_noise;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.IMUSensor.LinearAcceleration.x_noise)
}

// optional .gazebo.msgs.SensorNoise y_noise = 2;
inline bool IMUSensor_LinearAcceleration::_internal_has_y_noise() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || y_noise_ != nullptr);
  return value;
}
inline bool IMUSensor_LinearAcceleration::has_y_noise() const {
  return _internal_has_y_noise();
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_LinearAcceleration::_internal_y_noise() const {
  const ::gazebo::msgs::SensorNoise* p = y_noise_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::SensorNoise&>(
      ::gazebo::msgs::_SensorNoise_default_instance_);
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_LinearAcceleration::y_noise() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.IMUSensor.LinearAcceleration.y_noise)
  return _internal_y_noise();
}
inline void IMUSensor_LinearAcceleration::unsafe_arena_set_allocated_y_noise(
    ::gazebo::msgs::SensorNoise* y_noise) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(y_noise_);
  }
  y_noise_ = y_noise;
  if (y_noise) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.IMUSensor.LinearAcceleration.y_noise)
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::release_y_noise() {
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::SensorNoise* temp = y_noise_;
  y_noise_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::unsafe_arena_release_y_noise() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.IMUSensor.LinearAcceleration.y_noise)
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::SensorNoise* temp = y_noise_;
  y_noise_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::_internal_mutable_y_noise() {
  _has_bits_[0] |= 0x00000002u;
  if (y_noise_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::SensorNoise>(GetArenaForAllocation());
    y_noise_ = p;
  }
  return y_noise_;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::mutable_y_noise() {
  ::gazebo::msgs::SensorNoise* _msg = _internal_mutable_y_noise();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.IMUSensor.LinearAcceleration.y_noise)
  return _msg;
}
inline void IMUSensor_LinearAcceleration::set_allocated_y_noise(::gazebo::msgs::SensorNoise* y_noise) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(y_noise_);
  }
  if (y_noise) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(y_noise));
    if (message_arena != submessage_arena) {
      y_noise = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, y_noise, submessage_arena);
    }
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  y_noise_ = y_noise;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.IMUSensor.LinearAcceleration.y_noise)
}

// optional .gazebo.msgs.SensorNoise z_noise = 3;
inline bool IMUSensor_LinearAcceleration::_internal_has_z_noise() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  PROTOBUF_ASSUME(!value || z_noise_ != nullptr);
  return value;
}
inline bool IMUSensor_LinearAcceleration::has_z_noise() const {
  return _internal_has_z_noise();
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_LinearAcceleration::_internal_z_noise() const {
  const ::gazebo::msgs::SensorNoise* p = z_noise_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::SensorNoise&>(
      ::gazebo::msgs::_SensorNoise_default_instance_);
}
inline const ::gazebo::msgs::SensorNoise& IMUSensor_LinearAcceleration::z_noise() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.IMUSensor.LinearAcceleration.z_noise)
  return _internal_z_noise();
}
inline void IMUSensor_LinearAcceleration::unsafe_arena_set_allocated_z_noise(
    ::gazebo::msgs::SensorNoise* z_noise) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(z_noise_);
  }
  z_noise_ = z_noise;
  if (z_noise) {
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.IMUSensor.LinearAcceleration.z_noise)
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::release_z_noise() {
  _has_bits_[0] &= ~0x00000004u;
  ::gazebo::msgs::SensorNoise* temp = z_noise_;
  z_noise_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::unsafe_arena_release_z_noise() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.IMUSensor.LinearAcceleration.z_noise)
  _has_bits_[0] &= ~0x00000004u;
  ::gazebo::msgs::SensorNoise* temp = z_noise_;
  z_noise_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::_internal_mutable_z_noise() {
  _has_bits_[0] |= 0x00000004u;
  if (z_noise_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::SensorNoise>(GetArenaForAllocation());
    z_noise_ = p;
  }
  return z_noise_;
}
inline ::gazebo::msgs::SensorNoise* IMUSensor_LinearAcceleration::mutable_z_noise() {
  ::gazebo::msgs::SensorNoise* _msg = _internal_mutable_z_noise();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.IMUSensor.LinearAcceleration.z_noise)
  return _msg;
}
inline void IMUSensor_LinearAcceleration::set_allocated_z_noise(::gazebo::msgs::SensorNoise* z_noise) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(z_noise_);
  }
  if (z_noise) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(z_noise));
    if (message_arena != submessage_arena) {
      z_noise = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, z_noise, submessage_arena);
    }
    _has_bits_[0] |= 0x00000004u;
  } else {
    _has_bits_[0] &= ~0x00000004u;
  }
  z_noise_ = z_noise;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.IMUSensor.LinearAcceleration.z_noise)
}

// -------------------------------------------------------------------

// IMUSensor

// optional .gazebo.msgs.IMUSensor.AngularVelocity angular_velocity = 1;
inline bool IMUSensor::_internal_has_angular_velocity() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  PROTOBUF_ASSUME(!value || angular_velocity_ != nullptr);
  return value;
}
inline bool IMUSensor::has_angular_velocity() const {
  return _internal_has_angular_velocity();
}
inline void IMUSensor::clear_angular_velocity() {
  if (angular_velocity_ != nullptr) angular_velocity_->Clear();
  _has_bits_[0] &= ~0x00000001u;
}
inline const ::gazebo::msgs::IMUSensor_AngularVelocity& IMUSensor::_internal_angular_velocity() const {
  const ::gazebo::msgs::IMUSensor_AngularVelocity* p = angular_velocity_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::IMUSensor_AngularVelocity&>(
      ::gazebo::msgs::_IMUSensor_AngularVelocity_default_instance_);
}
inline const ::gazebo::msgs::IMUSensor_AngularVelocity& IMUSensor::angular_velocity() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.IMUSensor.angular_velocity)
  return _internal_angular_velocity();
}
inline void IMUSensor::unsafe_arena_set_allocated_angular_velocity(
    ::gazebo::msgs::IMUSensor_AngularVelocity* angular_velocity) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(angular_velocity_);
  }
  angular_velocity_ = angular_velocity;
  if (angular_velocity) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.IMUSensor.angular_velocity)
}
inline ::gazebo::msgs::IMUSensor_AngularVelocity* IMUSensor::release_angular_velocity() {
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::IMUSensor_AngularVelocity* temp = angular_velocity_;
  angular_velocity_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::IMUSensor_AngularVelocity* IMUSensor::unsafe_arena_release_angular_velocity() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.IMUSensor.angular_velocity)
  _has_bits_[0] &= ~0x00000001u;
  ::gazebo::msgs::IMUSensor_AngularVelocity* temp = angular_velocity_;
  angular_velocity_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::IMUSensor_AngularVelocity* IMUSensor::_internal_mutable_angular_velocity() {
  _has_bits_[0] |= 0x00000001u;
  if (angular_velocity_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::IMUSensor_AngularVelocity>(GetArenaForAllocation());
    angular_velocity_ = p;
  }
  return angular_velocity_;
}
inline ::gazebo::msgs::IMUSensor_AngularVelocity* IMUSensor::mutable_angular_velocity() {
  ::gazebo::msgs::IMUSensor_AngularVelocity* _msg = _internal_mutable_angular_velocity();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.IMUSensor.angular_velocity)
  return _msg;
}
inline void IMUSensor::set_allocated_angular_velocity(::gazebo::msgs::IMUSensor_AngularVelocity* angular_velocity) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete angular_velocity_;
  }
  if (angular_velocity) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::gazebo::msgs::IMUSensor_AngularVelocity>::GetOwningArena(angular_velocity);
    if (message_arena != submessage_arena) {
      angular_velocity = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, angular_velocity, submessage_arena);
    }
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  angular_velocity_ = angular_velocity;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.IMUSensor.angular_velocity)
}

// optional .gazebo.msgs.IMUSensor.LinearAcceleration linear_acceleration = 2;
inline bool IMUSensor::_internal_has_linear_acceleration() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || linear_acceleration_ != nullptr);
  return value;
}
inline bool IMUSensor::has_linear_acceleration() const {
  return _internal_has_linear_acceleration();
}
inline void IMUSensor::clear_linear_acceleration() {
  if (linear_acceleration_ != nullptr) linear_acceleration_->Clear();
  _has_bits_[0] &= ~0x00000002u;
}
inline const ::gazebo::msgs::IMUSensor_LinearAcceleration& IMUSensor::_internal_linear_acceleration() const {
  const ::gazebo::msgs::IMUSensor_LinearAcceleration* p = linear_acceleration_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::IMUSensor_LinearAcceleration&>(
      ::gazebo::msgs::_IMUSensor_LinearAcceleration_default_instance_);
}
inline const ::gazebo::msgs::IMUSensor_LinearAcceleration& IMUSensor::linear_acceleration() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.IMUSensor.linear_acceleration)
  return _internal_linear_acceleration();
}
inline void IMUSensor::unsafe_arena_set_allocated_linear_acceleration(
    ::gazebo::msgs::IMUSensor_LinearAcceleration* linear_acceleration) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(linear_acceleration_);
  }
  linear_acceleration_ = linear_acceleration;
  if (linear_acceleration) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.IMUSensor.linear_acceleration)
}
inline ::gazebo::msgs::IMUSensor_LinearAcceleration* IMUSensor::release_linear_acceleration() {
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::IMUSensor_LinearAcceleration* temp = linear_acceleration_;
  linear_acceleration_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::IMUSensor_LinearAcceleration* IMUSensor::unsafe_arena_release_linear_acceleration() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.IMUSensor.linear_acceleration)
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::IMUSensor_LinearAcceleration* temp = linear_acceleration_;
  linear_acceleration_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::IMUSensor_LinearAcceleration* IMUSensor::_internal_mutable_linear_acceleration() {
  _has_bits_[0] |= 0x00000002u;
  if (linear_acceleration_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::IMUSensor_LinearAcceleration>(GetArenaForAllocation());
    linear_acceleration_ = p;
  }
  return linear_acceleration_;
}
inline ::gazebo::msgs::IMUSensor_LinearAcceleration* IMUSensor::mutable_linear_acceleration() {
  ::gazebo::msgs::IMUSensor_LinearAcceleration* _msg = _internal_mutable_linear_acceleration();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.IMUSensor.linear_acceleration)
  return _msg;
}
inline void IMUSensor::set_allocated_linear_acceleration(::gazebo::msgs::IMUSensor_LinearAcceleration* linear_acceleration) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete linear_acceleration_;
  }
  if (linear_acceleration) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::gazebo::msgs::IMUSensor_LinearAcceleration>::GetOwningArena(linear_acceleration);
    if (message_arena != submessage_arena) {
      linear_acceleration = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, linear_acceleration, submessage_arena);
    }
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  linear_acceleration_ = linear_acceleration;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.IMUSensor.linear_acceleration)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------

// -------------------------------------------------------------------


typedef boost::shared_ptr<gazebo::msgs::IMUSensor> IMUSensorPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::IMUSensor const> ConstIMUSensorPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_imu_5fsensor_2eproto
