syntax = "proto2";
package gazebo.msgs;

/// \ingroup gazebo_msgs
/// \interface SphereGeom 
/// \brief Information about a sphere geometry

message SphereGeom
{
  /// \brief Radius of the sphere.
  required double radius  = 1;
}
