syntax = "proto2";
package gazebo.msgs;

/// \ingroup gazebo_msgs
/// \interface Selection
/// \brief A message for GUI selection data


message Selection
{
  required uint32 id     = 1;
  required string name   = 2;
  optional bool selected = 3 [default = false];
}
