#define TEST_INTEGRATION_PATH "D:/bld/gazebo_1647700150418/work/test/integration"
#define TEST_REGRESSION_PATH "D:/bld/gazebo_1647700150418/work/test/regression"
#define TEST_UNIT_PATH "D:/bld/gazebo_1647700150418/work/test/unit"
#define TEST_PATH "D:/bld/gazebo_1647700150418/work/test"
#define PROJECT_SOURCE_PATH "D:/bld/gazebo_1647700150418/work"
#define PROJECT_BINARY_PATH "D:/bld/gazebo_1647700150418/work/build"
