// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: axis.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_axis_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_axis_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3019000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3019004 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "vector3d.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_axis_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_axis_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const uint32_t offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_axis_2eproto;
namespace gazebo {
namespace msgs {
class Axis;
struct AxisDefaultTypeInternal;
GZ_MSGS_VISIBLE extern AxisDefaultTypeInternal _Axis_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::Axis* Arena::CreateMaybeMessage<::gazebo::msgs::Axis>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE Axis final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.Axis) */ {
 public:
  inline Axis() : Axis(nullptr) {}
  ~Axis() override;
  explicit constexpr Axis(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Axis(const Axis& from);
  Axis(Axis&& from) noexcept
    : Axis() {
    *this = ::std::move(from);
  }

  inline Axis& operator=(const Axis& from) {
    CopyFrom(from);
    return *this;
  }
  inline Axis& operator=(Axis&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Axis& default_instance() {
    return *internal_default_instance();
  }
  static inline const Axis* internal_default_instance() {
    return reinterpret_cast<const Axis*>(
               &_Axis_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Axis& a, Axis& b) {
    a.Swap(&b);
  }
  inline void Swap(Axis* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Axis* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Axis* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<Axis>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Axis& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Axis& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Axis* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.Axis";
  }
  protected:
  explicit Axis(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kXyzExpressedInFieldNumber = 9,
    kXyzFieldNumber = 1,
    kLimitLowerFieldNumber = 2,
    kLimitUpperFieldNumber = 3,
    kLimitEffortFieldNumber = 4,
    kLimitVelocityFieldNumber = 5,
    kDampingFieldNumber = 6,
    kFrictionFieldNumber = 7,
    kUseParentModelFrameFieldNumber = 8,
  };
  // required string xyz_expressed_in = 9;
  bool has_xyz_expressed_in() const;
  private:
  bool _internal_has_xyz_expressed_in() const;
  public:
  void clear_xyz_expressed_in();
  const std::string& xyz_expressed_in() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_xyz_expressed_in(ArgT0&& arg0, ArgT... args);
  std::string* mutable_xyz_expressed_in();
  PROTOBUF_NODISCARD std::string* release_xyz_expressed_in();
  void set_allocated_xyz_expressed_in(std::string* xyz_expressed_in);
  private:
  const std::string& _internal_xyz_expressed_in() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_xyz_expressed_in(const std::string& value);
  std::string* _internal_mutable_xyz_expressed_in();
  public:

  // required .gazebo.msgs.Vector3d xyz = 1;
  bool has_xyz() const;
  private:
  bool _internal_has_xyz() const;
  public:
  void clear_xyz();
  const ::gazebo::msgs::Vector3d& xyz() const;
  PROTOBUF_NODISCARD ::gazebo::msgs::Vector3d* release_xyz();
  ::gazebo::msgs::Vector3d* mutable_xyz();
  void set_allocated_xyz(::gazebo::msgs::Vector3d* xyz);
  private:
  const ::gazebo::msgs::Vector3d& _internal_xyz() const;
  ::gazebo::msgs::Vector3d* _internal_mutable_xyz();
  public:
  void unsafe_arena_set_allocated_xyz(
      ::gazebo::msgs::Vector3d* xyz);
  ::gazebo::msgs::Vector3d* unsafe_arena_release_xyz();

  // required double limit_lower = 2;
  bool has_limit_lower() const;
  private:
  bool _internal_has_limit_lower() const;
  public:
  void clear_limit_lower();
  double limit_lower() const;
  void set_limit_lower(double value);
  private:
  double _internal_limit_lower() const;
  void _internal_set_limit_lower(double value);
  public:

  // required double limit_upper = 3;
  bool has_limit_upper() const;
  private:
  bool _internal_has_limit_upper() const;
  public:
  void clear_limit_upper();
  double limit_upper() const;
  void set_limit_upper(double value);
  private:
  double _internal_limit_upper() const;
  void _internal_set_limit_upper(double value);
  public:

  // required double limit_effort = 4;
  bool has_limit_effort() const;
  private:
  bool _internal_has_limit_effort() const;
  public:
  void clear_limit_effort();
  double limit_effort() const;
  void set_limit_effort(double value);
  private:
  double _internal_limit_effort() const;
  void _internal_set_limit_effort(double value);
  public:

  // required double limit_velocity = 5;
  bool has_limit_velocity() const;
  private:
  bool _internal_has_limit_velocity() const;
  public:
  void clear_limit_velocity();
  double limit_velocity() const;
  void set_limit_velocity(double value);
  private:
  double _internal_limit_velocity() const;
  void _internal_set_limit_velocity(double value);
  public:

  // required double damping = 6;
  bool has_damping() const;
  private:
  bool _internal_has_damping() const;
  public:
  void clear_damping();
  double damping() const;
  void set_damping(double value);
  private:
  double _internal_damping() const;
  void _internal_set_damping(double value);
  public:

  // required double friction = 7;
  bool has_friction() const;
  private:
  bool _internal_has_friction() const;
  public:
  void clear_friction();
  double friction() const;
  void set_friction(double value);
  private:
  double _internal_friction() const;
  void _internal_set_friction(double value);
  public:

  // required bool use_parent_model_frame = 8 [deprecated = true];
  PROTOBUF_DEPRECATED bool has_use_parent_model_frame() const;
  private:
  bool _internal_has_use_parent_model_frame() const;
  public:
  PROTOBUF_DEPRECATED void clear_use_parent_model_frame();
  PROTOBUF_DEPRECATED bool use_parent_model_frame() const;
  PROTOBUF_DEPRECATED void set_use_parent_model_frame(bool value);
  private:
  bool _internal_use_parent_model_frame() const;
  void _internal_set_use_parent_model_frame(bool value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.Axis)
 private:
  class _Internal;

  // helper for ByteSizeLong()
  size_t RequiredFieldsByteSizeFallback() const;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr xyz_expressed_in_;
  ::gazebo::msgs::Vector3d* xyz_;
  double limit_lower_;
  double limit_upper_;
  double limit_effort_;
  double limit_velocity_;
  double damping_;
  double friction_;
  bool use_parent_model_frame_;
  friend struct ::TableStruct_axis_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Axis

// required .gazebo.msgs.Vector3d xyz = 1;
inline bool Axis::_internal_has_xyz() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  PROTOBUF_ASSUME(!value || xyz_ != nullptr);
  return value;
}
inline bool Axis::has_xyz() const {
  return _internal_has_xyz();
}
inline const ::gazebo::msgs::Vector3d& Axis::_internal_xyz() const {
  const ::gazebo::msgs::Vector3d* p = xyz_;
  return p != nullptr ? *p : reinterpret_cast<const ::gazebo::msgs::Vector3d&>(
      ::gazebo::msgs::_Vector3d_default_instance_);
}
inline const ::gazebo::msgs::Vector3d& Axis::xyz() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.xyz)
  return _internal_xyz();
}
inline void Axis::unsafe_arena_set_allocated_xyz(
    ::gazebo::msgs::Vector3d* xyz) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(xyz_);
  }
  xyz_ = xyz;
  if (xyz) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:gazebo.msgs.Axis.xyz)
}
inline ::gazebo::msgs::Vector3d* Axis::release_xyz() {
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::Vector3d* temp = xyz_;
  xyz_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::gazebo::msgs::Vector3d* Axis::unsafe_arena_release_xyz() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Axis.xyz)
  _has_bits_[0] &= ~0x00000002u;
  ::gazebo::msgs::Vector3d* temp = xyz_;
  xyz_ = nullptr;
  return temp;
}
inline ::gazebo::msgs::Vector3d* Axis::_internal_mutable_xyz() {
  _has_bits_[0] |= 0x00000002u;
  if (xyz_ == nullptr) {
    auto* p = CreateMaybeMessage<::gazebo::msgs::Vector3d>(GetArenaForAllocation());
    xyz_ = p;
  }
  return xyz_;
}
inline ::gazebo::msgs::Vector3d* Axis::mutable_xyz() {
  ::gazebo::msgs::Vector3d* _msg = _internal_mutable_xyz();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Axis.xyz)
  return _msg;
}
inline void Axis::set_allocated_xyz(::gazebo::msgs::Vector3d* xyz) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(xyz_);
  }
  if (xyz) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(xyz));
    if (message_arena != submessage_arena) {
      xyz = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, xyz, submessage_arena);
    }
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  xyz_ = xyz;
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Axis.xyz)
}

// required double limit_lower = 2;
inline bool Axis::_internal_has_limit_lower() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool Axis::has_limit_lower() const {
  return _internal_has_limit_lower();
}
inline void Axis::clear_limit_lower() {
  limit_lower_ = 0;
  _has_bits_[0] &= ~0x00000004u;
}
inline double Axis::_internal_limit_lower() const {
  return limit_lower_;
}
inline double Axis::limit_lower() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.limit_lower)
  return _internal_limit_lower();
}
inline void Axis::_internal_set_limit_lower(double value) {
  _has_bits_[0] |= 0x00000004u;
  limit_lower_ = value;
}
inline void Axis::set_limit_lower(double value) {
  _internal_set_limit_lower(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Axis.limit_lower)
}

// required double limit_upper = 3;
inline bool Axis::_internal_has_limit_upper() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool Axis::has_limit_upper() const {
  return _internal_has_limit_upper();
}
inline void Axis::clear_limit_upper() {
  limit_upper_ = 0;
  _has_bits_[0] &= ~0x00000008u;
}
inline double Axis::_internal_limit_upper() const {
  return limit_upper_;
}
inline double Axis::limit_upper() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.limit_upper)
  return _internal_limit_upper();
}
inline void Axis::_internal_set_limit_upper(double value) {
  _has_bits_[0] |= 0x00000008u;
  limit_upper_ = value;
}
inline void Axis::set_limit_upper(double value) {
  _internal_set_limit_upper(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Axis.limit_upper)
}

// required double limit_effort = 4;
inline bool Axis::_internal_has_limit_effort() const {
  bool value = (_has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool Axis::has_limit_effort() const {
  return _internal_has_limit_effort();
}
inline void Axis::clear_limit_effort() {
  limit_effort_ = 0;
  _has_bits_[0] &= ~0x00000010u;
}
inline double Axis::_internal_limit_effort() const {
  return limit_effort_;
}
inline double Axis::limit_effort() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.limit_effort)
  return _internal_limit_effort();
}
inline void Axis::_internal_set_limit_effort(double value) {
  _has_bits_[0] |= 0x00000010u;
  limit_effort_ = value;
}
inline void Axis::set_limit_effort(double value) {
  _internal_set_limit_effort(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Axis.limit_effort)
}

// required double limit_velocity = 5;
inline bool Axis::_internal_has_limit_velocity() const {
  bool value = (_has_bits_[0] & 0x00000020u) != 0;
  return value;
}
inline bool Axis::has_limit_velocity() const {
  return _internal_has_limit_velocity();
}
inline void Axis::clear_limit_velocity() {
  limit_velocity_ = 0;
  _has_bits_[0] &= ~0x00000020u;
}
inline double Axis::_internal_limit_velocity() const {
  return limit_velocity_;
}
inline double Axis::limit_velocity() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.limit_velocity)
  return _internal_limit_velocity();
}
inline void Axis::_internal_set_limit_velocity(double value) {
  _has_bits_[0] |= 0x00000020u;
  limit_velocity_ = value;
}
inline void Axis::set_limit_velocity(double value) {
  _internal_set_limit_velocity(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Axis.limit_velocity)
}

// required double damping = 6;
inline bool Axis::_internal_has_damping() const {
  bool value = (_has_bits_[0] & 0x00000040u) != 0;
  return value;
}
inline bool Axis::has_damping() const {
  return _internal_has_damping();
}
inline void Axis::clear_damping() {
  damping_ = 0;
  _has_bits_[0] &= ~0x00000040u;
}
inline double Axis::_internal_damping() const {
  return damping_;
}
inline double Axis::damping() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.damping)
  return _internal_damping();
}
inline void Axis::_internal_set_damping(double value) {
  _has_bits_[0] |= 0x00000040u;
  damping_ = value;
}
inline void Axis::set_damping(double value) {
  _internal_set_damping(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Axis.damping)
}

// required double friction = 7;
inline bool Axis::_internal_has_friction() const {
  bool value = (_has_bits_[0] & 0x00000080u) != 0;
  return value;
}
inline bool Axis::has_friction() const {
  return _internal_has_friction();
}
inline void Axis::clear_friction() {
  friction_ = 0;
  _has_bits_[0] &= ~0x00000080u;
}
inline double Axis::_internal_friction() const {
  return friction_;
}
inline double Axis::friction() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.friction)
  return _internal_friction();
}
inline void Axis::_internal_set_friction(double value) {
  _has_bits_[0] |= 0x00000080u;
  friction_ = value;
}
inline void Axis::set_friction(double value) {
  _internal_set_friction(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Axis.friction)
}

// required bool use_parent_model_frame = 8 [deprecated = true];
inline bool Axis::_internal_has_use_parent_model_frame() const {
  bool value = (_has_bits_[0] & 0x00000100u) != 0;
  return value;
}
inline bool Axis::has_use_parent_model_frame() const {
  return _internal_has_use_parent_model_frame();
}
inline void Axis::clear_use_parent_model_frame() {
  use_parent_model_frame_ = false;
  _has_bits_[0] &= ~0x00000100u;
}
inline bool Axis::_internal_use_parent_model_frame() const {
  return use_parent_model_frame_;
}
inline bool Axis::use_parent_model_frame() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.use_parent_model_frame)
  return _internal_use_parent_model_frame();
}
inline void Axis::_internal_set_use_parent_model_frame(bool value) {
  _has_bits_[0] |= 0x00000100u;
  use_parent_model_frame_ = value;
}
inline void Axis::set_use_parent_model_frame(bool value) {
  _internal_set_use_parent_model_frame(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.Axis.use_parent_model_frame)
}

// required string xyz_expressed_in = 9;
inline bool Axis::_internal_has_xyz_expressed_in() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool Axis::has_xyz_expressed_in() const {
  return _internal_has_xyz_expressed_in();
}
inline void Axis::clear_xyz_expressed_in() {
  xyz_expressed_in_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& Axis::xyz_expressed_in() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.Axis.xyz_expressed_in)
  return _internal_xyz_expressed_in();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Axis::set_xyz_expressed_in(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000001u;
 xyz_expressed_in_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.Axis.xyz_expressed_in)
}
inline std::string* Axis::mutable_xyz_expressed_in() {
  std::string* _s = _internal_mutable_xyz_expressed_in();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.Axis.xyz_expressed_in)
  return _s;
}
inline const std::string& Axis::_internal_xyz_expressed_in() const {
  return xyz_expressed_in_.Get();
}
inline void Axis::_internal_set_xyz_expressed_in(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  xyz_expressed_in_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Axis::_internal_mutable_xyz_expressed_in() {
  _has_bits_[0] |= 0x00000001u;
  return xyz_expressed_in_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Axis::release_xyz_expressed_in() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.Axis.xyz_expressed_in)
  if (!_internal_has_xyz_expressed_in()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  auto* p = xyz_expressed_in_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
#ifdef PROTOBUF_FORCE_COPY_DEFAULT_STRING
  if (xyz_expressed_in_.IsDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited())) {
    xyz_expressed_in_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), "", GetArenaForAllocation());
  }
#endif // PROTOBUF_FORCE_COPY_DEFAULT_STRING
  return p;
}
inline void Axis::set_allocated_xyz_expressed_in(std::string* xyz_expressed_in) {
  if (xyz_expressed_in != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  xyz_expressed_in_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), xyz_expressed_in,
      GetArenaForAllocation());
#ifdef PROTOBUF_FORCE_COPY_DEFAULT_STRING
  if (xyz_expressed_in_.IsDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited())) {
    xyz_expressed_in_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), "", GetArenaForAllocation());
  }
#endif // PROTOBUF_FORCE_COPY_DEFAULT_STRING
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.Axis.xyz_expressed_in)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::Axis> AxisPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::Axis const> ConstAxisPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_axis_2eproto
