// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: world_modify.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_world_5fmodify_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_world_5fmodify_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3019000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3019004 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#ifndef _MSC_VER
#pragma GCC system_header
#pragma GCC diagnostic ignored "-Wshadow"
#pragma GCC diagnostic ignored "-Wunused-parameter"
#endif
#include <boost/shared_ptr.hpp>
#include <gazebo/util/system.hh>
#include "gazebo/msgs/MsgFactory.hh"
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_world_5fmodify_2eproto GZ_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct GZ_MSGS_VISIBLE TableStruct_world_5fmodify_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const uint32_t offsets[];
};
GZ_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_world_5fmodify_2eproto;
namespace gazebo {
namespace msgs {
class WorldModify;
struct WorldModifyDefaultTypeInternal;
GZ_MSGS_VISIBLE extern WorldModifyDefaultTypeInternal _WorldModify_default_instance_;
}  // namespace msgs
}  // namespace gazebo
PROTOBUF_NAMESPACE_OPEN
template<> GZ_MSGS_VISIBLE ::gazebo::msgs::WorldModify* Arena::CreateMaybeMessage<::gazebo::msgs::WorldModify>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace gazebo {
namespace msgs {

// ===================================================================

class GZ_MSGS_VISIBLE WorldModify final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:gazebo.msgs.WorldModify) */ {
 public:
  inline WorldModify() : WorldModify(nullptr) {}
  ~WorldModify() override;
  explicit constexpr WorldModify(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  WorldModify(const WorldModify& from);
  WorldModify(WorldModify&& from) noexcept
    : WorldModify() {
    *this = ::std::move(from);
  }

  inline WorldModify& operator=(const WorldModify& from) {
    CopyFrom(from);
    return *this;
  }
  inline WorldModify& operator=(WorldModify&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet& unknown_fields() const {
    return _internal_metadata_.unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>(::PROTOBUF_NAMESPACE_ID::UnknownFieldSet::default_instance);
  }
  inline ::PROTOBUF_NAMESPACE_ID::UnknownFieldSet* mutable_unknown_fields() {
    return _internal_metadata_.mutable_unknown_fields<::PROTOBUF_NAMESPACE_ID::UnknownFieldSet>();
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const WorldModify& default_instance() {
    return *internal_default_instance();
  }
  static inline const WorldModify* internal_default_instance() {
    return reinterpret_cast<const WorldModify*>(
               &_WorldModify_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(WorldModify& a, WorldModify& b) {
    a.Swap(&b);
  }
  inline void Swap(WorldModify* other) {
    if (other == this) return;
  #ifdef PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() != nullptr &&
        GetOwningArena() == other->GetOwningArena()) {
   #else  // PROTOBUF_FORCE_COPY_IN_SWAP
    if (GetOwningArena() == other->GetOwningArena()) {
  #endif  // !PROTOBUF_FORCE_COPY_IN_SWAP
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(WorldModify* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  WorldModify* New(::PROTOBUF_NAMESPACE_ID::Arena* arena = nullptr) const final {
    return CreateMaybeMessage<WorldModify>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const WorldModify& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const WorldModify& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  uint8_t* _InternalSerialize(
      uint8_t* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(WorldModify* other);

  private:
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "gazebo.msgs.WorldModify";
  }
  protected:
  explicit WorldModify(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kWorldNameFieldNumber = 1,
    kClonedUriFieldNumber = 5,
    kRemoveFieldNumber = 2,
    kCreateFieldNumber = 3,
    kClonedFieldNumber = 4,
  };
  // required string world_name = 1;
  bool has_world_name() const;
  private:
  bool _internal_has_world_name() const;
  public:
  void clear_world_name();
  const std::string& world_name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_world_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_world_name();
  PROTOBUF_NODISCARD std::string* release_world_name();
  void set_allocated_world_name(std::string* world_name);
  private:
  const std::string& _internal_world_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_world_name(const std::string& value);
  std::string* _internal_mutable_world_name();
  public:

  // optional string cloned_uri = 5;
  bool has_cloned_uri() const;
  private:
  bool _internal_has_cloned_uri() const;
  public:
  void clear_cloned_uri();
  const std::string& cloned_uri() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_cloned_uri(ArgT0&& arg0, ArgT... args);
  std::string* mutable_cloned_uri();
  PROTOBUF_NODISCARD std::string* release_cloned_uri();
  void set_allocated_cloned_uri(std::string* cloned_uri);
  private:
  const std::string& _internal_cloned_uri() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_cloned_uri(const std::string& value);
  std::string* _internal_mutable_cloned_uri();
  public:

  // optional bool remove = 2;
  bool has_remove() const;
  private:
  bool _internal_has_remove() const;
  public:
  void clear_remove();
  bool remove() const;
  void set_remove(bool value);
  private:
  bool _internal_remove() const;
  void _internal_set_remove(bool value);
  public:

  // optional bool create = 3;
  bool has_create() const;
  private:
  bool _internal_has_create() const;
  public:
  void clear_create();
  bool create() const;
  void set_create(bool value);
  private:
  bool _internal_create() const;
  void _internal_set_create(bool value);
  public:

  // optional bool cloned = 4;
  bool has_cloned() const;
  private:
  bool _internal_has_cloned() const;
  public:
  void clear_cloned();
  bool cloned() const;
  void set_cloned(bool value);
  private:
  bool _internal_cloned() const;
  void _internal_set_cloned(bool value);
  public:

  // @@protoc_insertion_point(class_scope:gazebo.msgs.WorldModify)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::HasBits<1> _has_bits_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr world_name_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr cloned_uri_;
  bool remove_;
  bool create_;
  bool cloned_;
  friend struct ::TableStruct_world_5fmodify_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// WorldModify

// required string world_name = 1;
inline bool WorldModify::_internal_has_world_name() const {
  bool value = (_has_bits_[0] & 0x00000001u) != 0;
  return value;
}
inline bool WorldModify::has_world_name() const {
  return _internal_has_world_name();
}
inline void WorldModify::clear_world_name() {
  world_name_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000001u;
}
inline const std::string& WorldModify::world_name() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldModify.world_name)
  return _internal_world_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void WorldModify::set_world_name(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000001u;
 world_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldModify.world_name)
}
inline std::string* WorldModify::mutable_world_name() {
  std::string* _s = _internal_mutable_world_name();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.WorldModify.world_name)
  return _s;
}
inline const std::string& WorldModify::_internal_world_name() const {
  return world_name_.Get();
}
inline void WorldModify::_internal_set_world_name(const std::string& value) {
  _has_bits_[0] |= 0x00000001u;
  world_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* WorldModify::_internal_mutable_world_name() {
  _has_bits_[0] |= 0x00000001u;
  return world_name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* WorldModify::release_world_name() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.WorldModify.world_name)
  if (!_internal_has_world_name()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000001u;
  auto* p = world_name_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
#ifdef PROTOBUF_FORCE_COPY_DEFAULT_STRING
  if (world_name_.IsDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited())) {
    world_name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), "", GetArenaForAllocation());
  }
#endif // PROTOBUF_FORCE_COPY_DEFAULT_STRING
  return p;
}
inline void WorldModify::set_allocated_world_name(std::string* world_name) {
  if (world_name != nullptr) {
    _has_bits_[0] |= 0x00000001u;
  } else {
    _has_bits_[0] &= ~0x00000001u;
  }
  world_name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), world_name,
      GetArenaForAllocation());
#ifdef PROTOBUF_FORCE_COPY_DEFAULT_STRING
  if (world_name_.IsDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited())) {
    world_name_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), "", GetArenaForAllocation());
  }
#endif // PROTOBUF_FORCE_COPY_DEFAULT_STRING
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.WorldModify.world_name)
}

// optional bool remove = 2;
inline bool WorldModify::_internal_has_remove() const {
  bool value = (_has_bits_[0] & 0x00000004u) != 0;
  return value;
}
inline bool WorldModify::has_remove() const {
  return _internal_has_remove();
}
inline void WorldModify::clear_remove() {
  remove_ = false;
  _has_bits_[0] &= ~0x00000004u;
}
inline bool WorldModify::_internal_remove() const {
  return remove_;
}
inline bool WorldModify::remove() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldModify.remove)
  return _internal_remove();
}
inline void WorldModify::_internal_set_remove(bool value) {
  _has_bits_[0] |= 0x00000004u;
  remove_ = value;
}
inline void WorldModify::set_remove(bool value) {
  _internal_set_remove(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldModify.remove)
}

// optional bool create = 3;
inline bool WorldModify::_internal_has_create() const {
  bool value = (_has_bits_[0] & 0x00000008u) != 0;
  return value;
}
inline bool WorldModify::has_create() const {
  return _internal_has_create();
}
inline void WorldModify::clear_create() {
  create_ = false;
  _has_bits_[0] &= ~0x00000008u;
}
inline bool WorldModify::_internal_create() const {
  return create_;
}
inline bool WorldModify::create() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldModify.create)
  return _internal_create();
}
inline void WorldModify::_internal_set_create(bool value) {
  _has_bits_[0] |= 0x00000008u;
  create_ = value;
}
inline void WorldModify::set_create(bool value) {
  _internal_set_create(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldModify.create)
}

// optional bool cloned = 4;
inline bool WorldModify::_internal_has_cloned() const {
  bool value = (_has_bits_[0] & 0x00000010u) != 0;
  return value;
}
inline bool WorldModify::has_cloned() const {
  return _internal_has_cloned();
}
inline void WorldModify::clear_cloned() {
  cloned_ = false;
  _has_bits_[0] &= ~0x00000010u;
}
inline bool WorldModify::_internal_cloned() const {
  return cloned_;
}
inline bool WorldModify::cloned() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldModify.cloned)
  return _internal_cloned();
}
inline void WorldModify::_internal_set_cloned(bool value) {
  _has_bits_[0] |= 0x00000010u;
  cloned_ = value;
}
inline void WorldModify::set_cloned(bool value) {
  _internal_set_cloned(value);
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldModify.cloned)
}

// optional string cloned_uri = 5;
inline bool WorldModify::_internal_has_cloned_uri() const {
  bool value = (_has_bits_[0] & 0x00000002u) != 0;
  return value;
}
inline bool WorldModify::has_cloned_uri() const {
  return _internal_has_cloned_uri();
}
inline void WorldModify::clear_cloned_uri() {
  cloned_uri_.ClearToEmpty();
  _has_bits_[0] &= ~0x00000002u;
}
inline const std::string& WorldModify::cloned_uri() const {
  // @@protoc_insertion_point(field_get:gazebo.msgs.WorldModify.cloned_uri)
  return _internal_cloned_uri();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void WorldModify::set_cloned_uri(ArgT0&& arg0, ArgT... args) {
 _has_bits_[0] |= 0x00000002u;
 cloned_uri_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:gazebo.msgs.WorldModify.cloned_uri)
}
inline std::string* WorldModify::mutable_cloned_uri() {
  std::string* _s = _internal_mutable_cloned_uri();
  // @@protoc_insertion_point(field_mutable:gazebo.msgs.WorldModify.cloned_uri)
  return _s;
}
inline const std::string& WorldModify::_internal_cloned_uri() const {
  return cloned_uri_.Get();
}
inline void WorldModify::_internal_set_cloned_uri(const std::string& value) {
  _has_bits_[0] |= 0x00000002u;
  cloned_uri_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* WorldModify::_internal_mutable_cloned_uri() {
  _has_bits_[0] |= 0x00000002u;
  return cloned_uri_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* WorldModify::release_cloned_uri() {
  // @@protoc_insertion_point(field_release:gazebo.msgs.WorldModify.cloned_uri)
  if (!_internal_has_cloned_uri()) {
    return nullptr;
  }
  _has_bits_[0] &= ~0x00000002u;
  auto* p = cloned_uri_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
#ifdef PROTOBUF_FORCE_COPY_DEFAULT_STRING
  if (cloned_uri_.IsDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited())) {
    cloned_uri_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), "", GetArenaForAllocation());
  }
#endif // PROTOBUF_FORCE_COPY_DEFAULT_STRING
  return p;
}
inline void WorldModify::set_allocated_cloned_uri(std::string* cloned_uri) {
  if (cloned_uri != nullptr) {
    _has_bits_[0] |= 0x00000002u;
  } else {
    _has_bits_[0] &= ~0x00000002u;
  }
  cloned_uri_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), cloned_uri,
      GetArenaForAllocation());
#ifdef PROTOBUF_FORCE_COPY_DEFAULT_STRING
  if (cloned_uri_.IsDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited())) {
    cloned_uri_.Set(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), "", GetArenaForAllocation());
  }
#endif // PROTOBUF_FORCE_COPY_DEFAULT_STRING
  // @@protoc_insertion_point(field_set_allocated:gazebo.msgs.WorldModify.cloned_uri)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef boost::shared_ptr<gazebo::msgs::WorldModify> WorldModifyPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace gazebo

typedef const boost::shared_ptr<gazebo::msgs::WorldModify const> ConstWorldModifyPtr;
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_world_5fmodify_2eproto
