syntax = "proto2";
package gazebo.msgs;

/// \ingroup gazebo_msgs
/// \interface GUICamera 
/// \brief Message for a GUI Camera



import "pose.proto";
import "track_visual.proto";

message GUICamera
{
  required string name                  = 1;
  optional string view_controller       = 2;
  optional Pose pose                    = 3;
  optional TrackVisual track            = 4;

  /// \brief Type of projection: "perspective" or "orthographic".
  optional string projection_type       = 5;
}
